#ifndef CONFIGDIALOG_H
#define CONFIGDIALOG_H

#include <QDialog>

namespace Ui {
    class ConfigDialog;
}

class ConfigDialog : public QDialog
{
    Q_OBJECT

public:
    explicit ConfigDialog(QWidget *parent = 0);
    ~ConfigDialog();
    bool is_tagline_G();
    void set_tagline_G(bool value);
    bool is_tagline_non_G();
    void set_tagline_non_G(bool value);
    bool is_target_touch();
    void set_target_touch(bool value);
    bool is_target_full();
    void set_target_full(bool value);

signals:
    void do_unauthorize();

private:
    Ui::ConfigDialog *ui;
    bool _tagline_G;
    bool _tagline_non_G;
    bool _target_touch;
    bool _target_full;
    void update_ui();

private slots:
    void on_button_unauthorize_clicked();

};

#endif // CONFIGDIALOG_H
